Getting started
===============

Quickstart
-----------

1. :doc:`Get a copy <get-copy>` of the code.

2. Installation of a :doc:`Python environment <virtual-environment>` for PyKoala.

3. Running jupyter tutorials in a Python environment.


Contents
--------

.. toctree::
    :maxdepth: 1

    get-copy
    virtual-environment    
